jemm = Joint Exon Measure Model

this package faciliates the downstream statistical analysis of junction-based alternative splicing, using read counts from
 Darts (Zhang et al., 2019, Nature Methods) and SUPPA (Trincado et al., 2018, Genome Biology).

The main functions include:
- read and harmonize the PSIs from different measurements
- construct python class for storing and accessing such information
- perform differential analysis: generalized linear model, mixed model, linear regression


FZZ
2022.03.20



